==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1EndpointSubsetFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1EndpointSubsetFluent<A extends V1EndpointSubsetFluent<A>> extends Fluent<A>{


    public A addToAddresses(int index,V1EndpointAddress item);
    public A setToAddresses(int index,V1EndpointAddress item);
    public A addToAddresses(V1EndpointAddress... items);
    public A addAllToAddresses(Collection<V1EndpointAddress> items);
    public A removeFromAddresses(V1EndpointAddress... items);
    public A removeAllFromAddresses(Collection<V1EndpointAddress> items);
    
/**
 * This method has been deprecated, please use method buildAddresses instead.
 * @return The buildable object.
 */
@Deprecated public List<V1EndpointAddress> getAddresses();
    public List<V1EndpointAddress> buildAddresses();
    public V1EndpointAddress buildAddress(int index);
    public V1EndpointAddress buildFirstAddress();
    public V1EndpointAddress buildLastAddress();
    public V1EndpointAddress buildMatchingAddress(io.kubernetes.client.fluent.Predicate<V1EndpointAddressBuilder> predicate);
    public A withAddresses(List<V1EndpointAddress> addresses);
    public A withAddresses(V1EndpointAddress... addresses);
    public Boolean hasAddresses();
    public V1EndpointSubsetFluent.AddressesNested<A> addNewAddress();
    public V1EndpointSubsetFluent.AddressesNested<A> addNewAddressLike(V1EndpointAddress item);
    public V1EndpointSubsetFluent.AddressesNested<A> setNewAddressLike(int index,V1EndpointAddress item);
    public V1EndpointSubsetFluent.AddressesNested<A> editAddress(int index);
    public V1EndpointSubsetFluent.AddressesNested<A> editFirstAddress();
    public V1EndpointSubsetFluent.AddressesNested<A> editLastAddress();
    public V1EndpointSubsetFluent.AddressesNested<A> editMatchingAddress(io.kubernetes.client.fluent.Predicate<V1EndpointAddressBuilder> predicate);
    public A addToNotReadyAddresses(int index,V1EndpointAddress item);
    public A setToNotReadyAddresses(int index,V1EndpointAddress item);
    public A addToNotReadyAddresses(V1EndpointAddress... items);
    public A addAllToNotReadyAddresses(Collection<V1EndpointAddress> items);
    public A removeFromNotReadyAddresses(V1EndpointAddress... items);
    public A removeAllFromNotReadyAddresses(Collection<V1EndpointAddress> items);
    
/**
 * This method has been deprecated, please use method buildNotReadyAddresses instead.
 * @return The buildable object.
 */
@Deprecated public List<V1EndpointAddress> getNotReadyAddresses();
    public List<V1EndpointAddress> buildNotReadyAddresses();
    public V1EndpointAddress buildNotReadyAddress(int index);
    public V1EndpointAddress buildFirstNotReadyAddress();
    public V1EndpointAddress buildLastNotReadyAddress();
    public V1EndpointAddress buildMatchingNotReadyAddress(io.kubernetes.client.fluent.Predicate<V1EndpointAddressBuilder> predicate);
    public A withNotReadyAddresses(List<V1EndpointAddress> notReadyAddresses);
    public A withNotReadyAddresses(V1EndpointAddress... notReadyAddresses);
    public Boolean hasNotReadyAddresses();
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> addNewNotReadyAddress();
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> addNewNotReadyAddressLike(V1EndpointAddress item);
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> setNewNotReadyAddressLike(int index,V1EndpointAddress item);
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> editNotReadyAddress(int index);
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> editFirstNotReadyAddress();
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> editLastNotReadyAddress();
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> editMatchingNotReadyAddress(io.kubernetes.client.fluent.Predicate<V1EndpointAddressBuilder> predicate);
    public A addToPorts(int index,V1EndpointPort item);
    public A setToPorts(int index,V1EndpointPort item);
    public A addToPorts(V1EndpointPort... items);
    public A addAllToPorts(Collection<V1EndpointPort> items);
    public A removeFromPorts(V1EndpointPort... items);
    public A removeAllFromPorts(Collection<V1EndpointPort> items);
    
/**
 * This method has been deprecated, please use method buildPorts instead.
 * @return The buildable object.
 */
@Deprecated public List<V1EndpointPort> getPorts();
    public List<V1EndpointPort> buildPorts();
    public V1EndpointPort buildPort(int index);
    public V1EndpointPort buildFirstPort();
    public V1EndpointPort buildLastPort();
    public V1EndpointPort buildMatchingPort(io.kubernetes.client.fluent.Predicate<V1EndpointPortBuilder> predicate);
    public A withPorts(List<V1EndpointPort> ports);
    public A withPorts(V1EndpointPort... ports);
    public Boolean hasPorts();
    public V1EndpointSubsetFluent.PortsNested<A> addNewPort();
    public V1EndpointSubsetFluent.PortsNested<A> addNewPortLike(V1EndpointPort item);
    public V1EndpointSubsetFluent.PortsNested<A> setNewPortLike(int index,V1EndpointPort item);
    public V1EndpointSubsetFluent.PortsNested<A> editPort(int index);
    public V1EndpointSubsetFluent.PortsNested<A> editFirstPort();
    public V1EndpointSubsetFluent.PortsNested<A> editLastPort();
    public V1EndpointSubsetFluent.PortsNested<A> editMatchingPort(io.kubernetes.client.fluent.Predicate<V1EndpointPortBuilder> predicate);

    public interface AddressesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1EndpointAddressFluent<V1EndpointSubsetFluent.AddressesNested<N>>{

        
    public N and();    public N endAddress();
}
    public interface NotReadyAddressesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1EndpointAddressFluent<V1EndpointSubsetFluent.NotReadyAddressesNested<N>>{

        
    public N and();    public N endNotReadyAddress();
}
    public interface PortsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1EndpointPortFluent<V1EndpointSubsetFluent.PortsNested<N>>{

        
    public N and();    public N endPort();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1EndpointSubsetFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1EndpointSubsetFluent<A extends V1EndpointSubsetFluent<A>> extends Fluent<A>{


    public A addToAddresses(int index,V1EndpointAddress item);
    public A setToAddresses(int index,V1EndpointAddress item);
    public A addToAddresses(V1EndpointAddress... items);
    public A addAllToAddresses(Collection<V1EndpointAddress> items);
    public A removeFromAddresses(V1EndpointAddress... items);
    public A removeAllFromAddresses(Collection<V1EndpointAddress> items);
    
/**
 * This method has been deprecated, please use method buildAddresses instead.
 * @return The buildable object.
 */
@Deprecated public List<V1EndpointAddress> getAddresses();
    public List<V1EndpointAddress> buildAddresses();
    public V1EndpointAddress buildAddress(int index);
    public V1EndpointAddress buildFirstAddress();
    public V1EndpointAddress buildLastAddress();
    public V1EndpointAddress buildMatchingAddress(io.kubernetes.client.fluent.Predicate<V1EndpointAddressBuilder> predicate);
    public Boolean hasMatchingAddress(io.kubernetes.client.fluent.Predicate<V1EndpointAddressBuilder> predicate);
    public A withAddresses(List<V1EndpointAddress> addresses);
    public A withAddresses(V1EndpointAddress... addresses);
    public Boolean hasAddresses();
    public V1EndpointSubsetFluent.AddressesNested<A> addNewAddress();
    public V1EndpointSubsetFluent.AddressesNested<A> addNewAddressLike(V1EndpointAddress item);
    public V1EndpointSubsetFluent.AddressesNested<A> setNewAddressLike(int index,V1EndpointAddress item);
    public V1EndpointSubsetFluent.AddressesNested<A> editAddress(int index);
    public V1EndpointSubsetFluent.AddressesNested<A> editFirstAddress();
    public V1EndpointSubsetFluent.AddressesNested<A> editLastAddress();
    public V1EndpointSubsetFluent.AddressesNested<A> editMatchingAddress(io.kubernetes.client.fluent.Predicate<V1EndpointAddressBuilder> predicate);
    public A addToNotReadyAddresses(int index,V1EndpointAddress item);
    public A setToNotReadyAddresses(int index,V1EndpointAddress item);
    public A addToNotReadyAddresses(V1EndpointAddress... items);
    public A addAllToNotReadyAddresses(Collection<V1EndpointAddress> items);
    public A removeFromNotReadyAddresses(V1EndpointAddress... items);
    public A removeAllFromNotReadyAddresses(Collection<V1EndpointAddress> items);
    
/**
 * This method has been deprecated, please use method buildNotReadyAddresses instead.
 * @return The buildable object.
 */
@Deprecated public List<V1EndpointAddress> getNotReadyAddresses();
    public List<V1EndpointAddress> buildNotReadyAddresses();
    public V1EndpointAddress buildNotReadyAddress(int index);
    public V1EndpointAddress buildFirstNotReadyAddress();
    public V1EndpointAddress buildLastNotReadyAddress();
    public V1EndpointAddress buildMatchingNotReadyAddress(io.kubernetes.client.fluent.Predicate<V1EndpointAddressBuilder> predicate);
    public Boolean hasMatchingNotReadyAddress(io.kubernetes.client.fluent.Predicate<V1EndpointAddressBuilder> predicate);
    public A withNotReadyAddresses(List<V1EndpointAddress> notReadyAddresses);
    public A withNotReadyAddresses(V1EndpointAddress... notReadyAddresses);
    public Boolean hasNotReadyAddresses();
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> addNewNotReadyAddress();
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> addNewNotReadyAddressLike(V1EndpointAddress item);
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> setNewNotReadyAddressLike(int index,V1EndpointAddress item);
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> editNotReadyAddress(int index);
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> editFirstNotReadyAddress();
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> editLastNotReadyAddress();
    public V1EndpointSubsetFluent.NotReadyAddressesNested<A> editMatchingNotReadyAddress(io.kubernetes.client.fluent.Predicate<V1EndpointAddressBuilder> predicate);
    public A addToPorts(int index,V1EndpointPort item);
    public A setToPorts(int index,V1EndpointPort item);
    public A addToPorts(V1EndpointPort... items);
    public A addAllToPorts(Collection<V1EndpointPort> items);
    public A removeFromPorts(V1EndpointPort... items);
    public A removeAllFromPorts(Collection<V1EndpointPort> items);
    
/**
 * This method has been deprecated, please use method buildPorts instead.
 * @return The buildable object.
 */
@Deprecated public List<V1EndpointPort> getPorts();
    public List<V1EndpointPort> buildPorts();
    public V1EndpointPort buildPort(int index);
    public V1EndpointPort buildFirstPort();
    public V1EndpointPort buildLastPort();
    public V1EndpointPort buildMatchingPort(io.kubernetes.client.fluent.Predicate<V1EndpointPortBuilder> predicate);
    public Boolean hasMatchingPort(io.kubernetes.client.fluent.Predicate<V1EndpointPortBuilder> predicate);
    public A withPorts(List<V1EndpointPort> ports);
    public A withPorts(V1EndpointPort... ports);
    public Boolean hasPorts();
    public V1EndpointSubsetFluent.PortsNested<A> addNewPort();
    public V1EndpointSubsetFluent.PortsNested<A> addNewPortLike(V1EndpointPort item);
    public V1EndpointSubsetFluent.PortsNested<A> setNewPortLike(int index,V1EndpointPort item);
    public V1EndpointSubsetFluent.PortsNested<A> editPort(int index);
    public V1EndpointSubsetFluent.PortsNested<A> editFirstPort();
    public V1EndpointSubsetFluent.PortsNested<A> editLastPort();
    public V1EndpointSubsetFluent.PortsNested<A> editMatchingPort(io.kubernetes.client.fluent.Predicate<V1EndpointPortBuilder> predicate);

    public interface AddressesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1EndpointAddressFluent<V1EndpointSubsetFluent.AddressesNested<N>>{

        
    public N and();    public N endAddress();
}
    public interface NotReadyAddressesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1EndpointAddressFluent<V1EndpointSubsetFluent.NotReadyAddressesNested<N>>{

        
    public N and();    public N endNotReadyAddress();
}
    public interface PortsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1EndpointPortFluent<V1EndpointSubsetFluent.PortsNested<N>>{

        
    public N and();    public N endPort();
}


}
